UNIT FormMain;

INTERFACE

USES
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, DirectShow9, ComObj, ActiveX, ExtCtrls, ComCtrls,
  TermiPlayer;

CONST
  WM_MEDIA_NOTIFY = WM_USER + 1000;  

TYPE
  TMainForm = class(TForm)
    panelVideo: TPanel;
    trackBarProgress: TTrackBar;
    buttonPlay: TButton;
    buttonPause: TButton;
    buttonPrev: TButton;
    buttonNext: TButton;
    timerRefresh: TTimer;
    buttonOpen: TButton;
    openDialogVideo: TOpenDialog;
    buttonFast: TButton;
    buttonSlow: TButton;
    trackBarVolume: TTrackBar;
    buttonStop: TButton;
    labelVolume: TLabel;
    labelBalance: TLabel;
    trackBarBalance: TTrackBar;
    eFasterSpeed: TEdit;
    eSlowSpeed: TEdit;
    Button2: TButton;
    TermiPlayer1: TTermiPlayer;
    procedure FormResize(Sender: TObject);
    procedure buttonCaptureClick(Sender: TObject);
    procedure buttonPlayClick(Sender: TObject);
    procedure buttonPauseClick(Sender: TObject);
    procedure buttonNextClick(Sender: TObject);
    procedure buttonPrevClick(Sender: TObject);
    procedure trackBarProgressChange(Sender: TObject);
    procedure timerRefreshTimer(Sender: TObject);
    procedure buttonOpenClick(Sender: TObject);
    procedure FormMouseDown(Sender: TObject; Button: TMouseButton;
      Shift: TShiftState; X, Y: Integer);
    procedure buttonFastClick(Sender: TObject);
    procedure buttonSlowClick(Sender: TObject);
    procedure trackBarVolumeChange(Sender: TObject);
    procedure buttonStopClick(Sender: TObject);
    procedure trackBarBalanceChange(Sender: TObject);
    procedure Button2Click(Sender: TObject);
    procedure FormCreate(Sender: TObject);
  PRIVATE
    FPositioning: boolean;
    procedure MediaNotify(var Msg: Tmessage); message WM_MEDIA_NOTIFY;
  PUBLIC
  END;

VAR
  MainForm: TMainForm;
  Counter: integer = 1;

IMPLEMENTATION

{$R *.dfm}
//        
procedure TMainForm.FormResize(Sender: TObject);
begin
  TermiPlayer1.SetWindowPosition(Rect(0, 0, panelVideo.ClientRect.Right,
    panelVideo.ClientRect.Bottom));
end;

//                   
procedure TMainForm.buttonCaptureClick(Sender: TObject);
begin
  if SUCCEEDED(TermiPlayer1.CaptureBitmap(ExtractFileDir(Application.ExeName) +
    Format('\cap%d.bmp', [Counter]))) then
  begin
    //    
    inc(Counter);
  end;
end;

//                             
procedure TMainForm.buttonPlayClick(Sender: TObject);
begin
  TermiPlayer1.Play;
end;

//                                     
procedure TMainForm.buttonStopClick(Sender: TObject);
begin
  TermiPlayer1.Stop;
end;

//                        
procedure TMainForm.buttonPauseClick(Sender: TObject);
begin
  TermiPlayer1.Pause
end;

//                                              
procedure TMainForm.buttonNextClick(Sender: TObject);
begin
  TermiPlayer1.StepNext;
end;

//                                               
procedure TMainForm.buttonPrevClick(Sender: TObject);
begin
  TermiPlayer1.StepPrev;
end;

//                         
procedure TMainForm.trackBarProgressChange(Sender: TObject);
begin
  if FPositioning then EXIT;

  FPositioning := TRUE;
  try
    TermiPlayer1.Position := trackBarProgress.Position * 100;
  finally
    FPositioning := FALSE;
  end;
end;

//                      
procedure TMainForm.timerRefreshTimer(Sender: TObject);
var
  P: int64;
begin
  if FPositioning then EXIT;

  FPositioning := TRUE;
  try
    if SUCCEEDED(TermiPlayer1.GetPlayingPosition(P)) then
       trackBarProgress.Position := P div 100;
  finally
    FPositioning := FALSE;
  end;
end;

//                               
procedure TMainForm.buttonOpenClick(Sender: TObject);
var
  Volume: longint;
begin
  if openDialogVideo.Execute then
  begin
    if SUCCEEDED(TermiPlayer1.Initialize(WideString(openDialogVideo.FileName))) then
    begin
      Caption := 'Small Media Player: ' + openDialogVideo.FileName;

      trackBarProgress.Max := TermiPlayer1.FrameCount div 100;

      TermiPlayer1.RegisterEventMessage(Handle, WM_MEDIA_NOTIFY);
      
      TermiPlayer1.SetWindowPosition(Rect(0, 0, panelVideo.ClientRect.Right,
        panelVideo.ClientRect.Bottom));
        
      trackBarVolume.Position := 10 - TermiPlayer1.Volume div 100;

      // ,    
      TermiPlayer1.PutOwner(panelVideo.Handle);
    end;
  end;
end;

//                                     
procedure TMainForm.FormMouseDown(Sender: TObject; Button: TMouseButton;
  Shift: TShiftState; X, Y: Integer);
begin
  ReleaseCapture;
  SendMessage(Handle, WM_NCLBUTTONDOWN, HTCAPTION, 0);
end;

//                                      
procedure TMainForm.buttonFastClick(Sender: TObject);
var
 FasterSpeed: double;
begin
 FasterSpeed := StrToFloat(eFasterSpeed.Text);

 TermiPlayer1.Faster(FasterSpeed);
end;

//                                     
procedure TMainForm.buttonSlowClick(Sender: TObject);
var
 SlowSpeed: double;
 Pos: int64;
begin
 SlowSpeed := StrToFloat(eSlowSpeed.Text);

 TermiPlayer1.Slower(SlowSpeed);
end;

//                                    
procedure TMainForm.trackBarVolumeChange(Sender: TObject);
begin
  TermiPlayer1.Volume := trackBarVolume.Position * 100;
end;

//    TermiPlayer1                
procedure TMainForm.MediaNotify(var Msg: Tmessage);
var
  EventCode: Integer;
  Param1, Param2: Integer;
begin
  while TermiPlayer1.GetEvent(EventCode, Param1, Param2, 0) = S_OK do
  begin
    if EventCode = EC_Complete then
    begin
      TermiPlayer1.Stop;
      TermiPlayer1.SetPlayingPosition(0);
    end;
  end;
end;

// 
procedure TMainForm.trackBarBalanceChange(Sender: TObject);
begin
  TermiPlayer1.Balance := trackBarBalance.Position;
end;

procedure TMainForm.Button2Click(Sender: TObject);
begin
 TermiPlayer1.SetFullScreen(TRUE);
end;

procedure TMainForm.FormCreate(Sender: TObject);
begin
 TermiPlayer1.PutOwner(panelVideo.Handle);
end;

END.
